@@ -98,6 +98,7 @@ static gboolean notify_get_server_information(XfceNotifyDaemon *daemon,
                                               gchar **OUT_name,
                                               gchar **OUT_vendor,
                                               gchar **OUT_version,
+                                              gchar **OUT_spec_version,
                                               GError **error);
 
 static gboolean notify_quit(XfceNotifyDaemon *daemon,
@@ -125,15 +126,10 @@ xfce_notify_daemon_class_init(XfceNotifyDaemonClass *klass)
                                                     G_SIGNAL_RUN_LAST,
                                                     0,
                                                     NULL, NULL,
-                                                    g_cclosure_marshal_VOID__UINT,
-                                                    G_TYPE_NONE, 1,
-                                                    G_TYPE_UINT);
-#if 0  /* it seems libnotify doesn't support the close-reason arg */
                                                     xfce_notify_marshal_VOID__UINT_UINT,
                                                     G_TYPE_NONE, 2,
                                                     G_TYPE_UINT,
                                                     G_TYPE_UINT);
-#endif
     signals[SIG_ACTION_INVOKED] = g_signal_new("action-invoked",
                                                XFCE_TYPE_NOTIFY_DAEMON,
                                                G_SIGNAL_RUN_LAST,
@@ -215,9 +211,7 @@ xfce_notify_daemon_window_closed(XfceNotifyWindow *window,
 
     g_tree_remove(daemon->active_notifications, id_p);
     g_signal_emit(G_OBJECT(daemon), signals[SIG_NOTIFICATION_CLOSED], 0,
-                  GPOINTER_TO_UINT(id_p));
-    /* NOTE: libnotify doesn't support the close-reason argument to
-     * the signal.  not sure why. */
+                  GPOINTER_TO_UINT(id_p), reason);
 }
 
 static void
@@ -419,11 +413,13 @@ notify_get_server_information(XfceNotifyDaemon *daemon,
                               gchar **OUT_name,
                               gchar **OUT_vendor,
                               gchar **OUT_version,
+                              gchar **OUT_spec_version,
                               GError **error)
 {
     *OUT_name = g_strdup("Xfce Notify Daemon");
     *OUT_vendor = g_strdup("Xfce");
     *OUT_version = g_strdup(VERSION);
+    *OUT_spec_version = g_strdup(NOTIFICATIONS_SPEC_VERSION);
 
     return TRUE;
 }
